@@ -1,14 +1,15 @@
 from itertools import chain
-from typing import Dict, List, Optional, Sequence, Set, Tuple, Union, cast
+from typing import Any, Dict, List, Optional, Tuple, Union, cast
 
 from ...error import GraphQLError
 from ...language import (
-    ArgumentNode,
+    DirectiveNode,
     FieldNode,
     FragmentDefinitionNode,
     FragmentSpreadNode,
     InlineFragmentNode,
     SelectionSetNode,
+    ValueNode,
     print_ast,
 )
 from ...type import (
@@ -26,31 +27,20 @@ from ...type import (
     is_object_type,
 )
 from ...utilities import type_from_ast
+from ...utilities.sort_value_node import sort_value_node
 from . import ValidationContext, ValidationRule
 
 MYPY = False
 
-__all__ = [
-    "OverlappingFieldsCanBeMergedRule",
-    "fields_conflict_message",
-    "reason_message",
-]
-
-
-def fields_conflict_message(response_name: str, reason: "ConflictReasonMessage") -> str:
-    return (
-        f"Fields '{response_name}' conflict because {reason_message(reason)}."
-        " Use different aliases on the fields to fetch both if this was"
-        " intentional."
-    )
+__all__ = ["OverlappingFieldsCanBeMergedRule"]
 
 
 def reason_message(reason: "ConflictReasonMessage") -> str:
     if isinstance(reason, list):
         return " and ".join(
             f"subfields '{response_name}' conflict"
-            f" because {reason_message(subreason)}"
-            for response_name, subreason in reason
+            f" because {reason_message(sub_reason)}"
+            for response_name, sub_reason in reason
         )
     return reason
 
@@ -60,9 +50,11 @@ class OverlappingFieldsCanBeMergedRule(ValidationRule):
 
     A selection set is only valid if all fields (including spreading any fragments)
     either correspond to distinct response names or can be merged without ambiguity.
+
+    See https://spec.graphql.org/draft/#sec-Field-Selection-Merging
     """
 
-    def __init__(self, context: ValidationContext) -> None:
+    def __init__(self, context: ValidationContext):
         super().__init__(context)
         # A memoization for when two fragments are compared "between" each other for
         # conflicts. Two fragments may be compared many times, so memoizing this can
@@ -74,7 +66,7 @@ class OverlappingFieldsCanBeMergedRule(ValidationRule):
         # times, so this improves the performance of this validator.
         self.cached_fields_and_fragment_names: Dict = {}
 
-    def enter_selection_set(self, selection_set: SelectionSetNode, *_args):
+    def enter_selection_set(self, selection_set: SelectionSetNode, *_args: Any) -> None:
         conflicts = find_conflicts_within_selection_set(
             self.context,
             self.cached_fields_and_fragment_names,
@@ -83,9 +75,13 @@ class OverlappingFieldsCanBeMergedRule(ValidationRule):
             selection_set,
         )
         for (reason_name, reason), fields1, fields2 in conflicts:
+            reason_msg = reason_message(reason)
             self.report_error(
                 GraphQLError(
-                    fields_conflict_message(reason_name, reason), fields1 + fields2
+                    f"Fields '{reason_name}' conflict because {reason_msg}."
+                    " Use different aliases on the fields to fetch both"
+                    " if this was intentional.",
+                    fields1 + fields2,
                 )
             )
 
@@ -188,7 +184,6 @@ def find_conflicts_within_selection_set(
     )
 
     if fragment_names:
-        compared_fragments: Set[str] = set()
         # (B) Then collect conflicts between these fields and those represented by each
         # spread fragment name found.
         for i, fragment_name in enumerate(fragment_names):
@@ -196,7 +191,6 @@ def find_conflicts_within_selection_set(
                 context,
                 conflicts,
                 cached_fields_and_fragment_names,
-                compared_fragments,
                 compared_fragment_pairs,
                 False,
                 field_map,
@@ -224,7 +218,6 @@ def collect_conflicts_between_fields_and_fragment(
     context: ValidationContext,
     conflicts: List[Conflict],
     cached_fields_and_fragment_names: Dict,
-    compared_fragments: Set[str],
     compared_fragment_pairs: "PairSet",
     are_mutually_exclusive: bool,
     field_map: NodeAndDefCollection,
@@ -235,16 +228,11 @@ def collect_conflicts_between_fields_and_fragment(
     Collect all conflicts found between a set of fields and a fragment reference
     including via spreading in any nested fragments.
     """
-    # Memoize so a fragment is not compared for conflicts more than once.
-    if fragment_name in compared_fragments:
-        return
-    compared_fragments.add(fragment_name)
-
     fragment = context.get_fragment(fragment_name)
     if not fragment:
         return None
 
-    field_map2, fragment_names2 = get_referenced_fields_and_fragment_names(
+    field_map2, referenced_fragment_names = get_referenced_fields_and_fragment_names(
         context, cached_fields_and_fragment_names, fragment
     )
 
@@ -266,16 +254,24 @@ def collect_conflicts_between_fields_and_fragment(
 
     # (E) Then collect any conflicts between the provided collection of fields and any
     # fragment names found in the given fragment.
-    for fragment_name2 in fragment_names2:
+    for referenced_fragment_name in referenced_fragment_names:
+        # Memoize so two fragments are not compared for conflicts more than once.
+        if compared_fragment_pairs.has(
+            referenced_fragment_name, fragment_name, are_mutually_exclusive
+        ):
+            continue
+        compared_fragment_pairs.add(
+            referenced_fragment_name, fragment_name, are_mutually_exclusive
+        )
+
         collect_conflicts_between_fields_and_fragment(
             context,
             conflicts,
             cached_fields_and_fragment_names,
-            compared_fragments,
             compared_fragment_pairs,
             are_mutually_exclusive,
             field_map,
-            fragment_name2,
+            referenced_fragment_name,
         )
 
 
@@ -309,11 +305,11 @@ def collect_conflicts_between_fragments(
     if not fragment1 or not fragment2:
         return None
 
-    field_map1, fragment_names1 = get_referenced_fields_and_fragment_names(
+    field_map1, referenced_fragment_names1 = get_referenced_fields_and_fragment_names(
         context, cached_fields_and_fragment_names, fragment1
     )
 
-    field_map2, fragment_names2 = get_referenced_fields_and_fragment_names(
+    field_map2, referenced_fragment_names2 = get_referenced_fields_and_fragment_names(
         context, cached_fields_and_fragment_names, fragment2
     )
 
@@ -331,7 +327,7 @@ def collect_conflicts_between_fragments(
 
     # (G) Then collect conflicts between the first fragment and any nested fragments
     # spread in the second fragment.
-    for nested_fragment_name2 in fragment_names2:
+    for referenced_fragment_name2 in referenced_fragment_names2:
         collect_conflicts_between_fragments(
             context,
             conflicts,
@@ -339,19 +335,19 @@ def collect_conflicts_between_fragments(
             compared_fragment_pairs,
             are_mutually_exclusive,
             fragment_name1,
-            nested_fragment_name2,
+            referenced_fragment_name2,
         )
 
     # (G) Then collect conflicts between the second fragment and any nested fragments
     # spread in the first fragment.
-    for nested_fragment_name1 in fragment_names1:
+    for referenced_fragment_name1 in referenced_fragment_names1:
         collect_conflicts_between_fragments(
             context,
             conflicts,
             cached_fields_and_fragment_names,
             compared_fragment_pairs,
             are_mutually_exclusive,
-            nested_fragment_name1,
+            referenced_fragment_name1,
             fragment_name2,
         )
 
@@ -395,13 +391,11 @@ def find_conflicts_between_sub_selection_sets(
     # (I) Then collect conflicts between the first collection of fields and those
     # referenced by each fragment name associated with the second.
     if fragment_names2:
-        compared_fragments: Set[str] = set()
         for fragment_name2 in fragment_names2:
             collect_conflicts_between_fields_and_fragment(
                 context,
                 conflicts,
                 cached_fields_and_fragment_names,
-                compared_fragments,
                 compared_fragment_pairs,
                 are_mutually_exclusive,
                 field_map1,
@@ -411,13 +405,11 @@ def find_conflicts_between_sub_selection_sets(
     # (I) Then collect conflicts between the second collection of fields and those
     # referenced by each fragment name associated with the first.
     if fragment_names1:
-        compared_fragments = set()
         for fragment_name1 in fragment_names1:
             collect_conflicts_between_fields_and_fragment(
                 context,
                 conflicts,
                 cached_fields_and_fragment_names,
-                compared_fragments,
                 compared_fragment_pairs,
                 are_mutually_exclusive,
                 field_map2,
@@ -486,10 +478,10 @@ def collect_conflicts_between(
 ) -> None:
     """Collect all Conflicts between two collections of fields.
 
-    This is similar to, but different from the `collectConflictsWithin` function above.
-    This check assumes that `collectConflictsWithin` has already been called on each
-    provided collection of fields. This is true because this validator traverses each
-    individual selection set.
+    This is similar to, but different from the :func:`~.collect_conflicts_within`
+    function above. This check assumes that :func:`~.collect_conflicts_within` has
+    already been called on each provided collection of fields. This is true because
+    this validator traverses each individual selection set.
     """
     # A field map is a keyed collection, where each key represents a response name and
     # the value at that key is a list of all fields which provide that response name.
@@ -553,18 +545,18 @@ def find_conflict(
         name2 = node2.name.value
         if name1 != name2:
             return (
-                (response_name, f"{name1} and {name2} are different fields"),
+                (response_name, f"'{name1}' and '{name2}' are different fields"),
                 [node1],
                 [node2],
             )
 
         # Two field calls must have the same arguments.
-        if not same_arguments(node1.arguments or [], node2.arguments or []):
+        if not same_arguments(node1, node2):
             return (response_name, "they have differing arguments"), [node1], [node2]
 
     if type1 and type2 and do_types_conflict(type1, type2):
         return (
-            (response_name, f"they return conflicting types {type1} and {type2}"),
+            (response_name, f"they return conflicting types '{type1}' and '{type2}'"),
             [node1],
             [node2],
         )
@@ -591,23 +583,33 @@ def find_conflict(
 
 
 def same_arguments(
-    arguments1: Sequence[ArgumentNode], arguments2: Sequence[ArgumentNode]
+    node1: Union[FieldNode, DirectiveNode], node2: Union[FieldNode, DirectiveNode]
 ) -> bool:
-    if len(arguments1) != len(arguments2):
+    args1 = node1.arguments
+    args2 = node2.arguments
+
+    if not args1:
+        return not args2
+
+    if not args2:
         return False
-    for argument1 in arguments1:
-        for argument2 in arguments2:
-            if argument2.name.value == argument1.name.value:
-                if not same_value(argument1.value, argument2.value):
-                    return False
-                break
-        else:
+
+    if len(args1) != len(args2):
+        return False  # pragma: no cover
+
+    values2 = {arg.name.value: arg.value for arg in args2}
+
+    for arg1 in args1:
+        value1 = arg1.value
+        value2 = values2.get(arg1.name.value)
+        if value2 is None or stringify_value(value1) != stringify_value(value2):
             return False
+
     return True
 
 
-def same_value(value1, value2):
-    return (not value1 and not value2) or (print_ast(value1) == print_ast(value2))
+def stringify_value(value: ValueNode) -> str:
+    return print_ast(sort_value_node(value))
 
 
 def do_types_conflict(type1: GraphQLOutputType, type2: GraphQLOutputType) -> bool:
@@ -710,7 +712,7 @@ def collect_fields_and_fragment_names(
             )
         elif isinstance(selection, FragmentSpreadNode):
             fragment_names[selection.name.value] = True
-        elif isinstance(selection, InlineFragmentNode):
+        elif isinstance(selection, InlineFragmentNode):  # pragma: no cover else
             type_condition = selection.type_condition
             inline_fragment_type = (
                 type_from_ast(context.schema, type_condition)
@@ -746,34 +748,36 @@ def subfield_conflicts(
 class PairSet:
     """Pair set
 
-    A way to keep track of pairs of things when the ordering of the pair does not
-    matter. We do this by maintaining a sort of double adjacency sets.
+    A way to keep track of pairs of things when the ordering of the pair doesn't matter.
     """
 
     __slots__ = ("_data",)
 
-    def __init__(self):
-        self._data: Dict[str, Dict[str, bool]] = {}
+    _data: Dict[str, Dict[str, bool]]
 
-    def has(self, a: str, b: str, are_mutually_exclusive: bool):
-        first = self._data.get(a)
-        result = first and first.get(b)
+    def __init__(self) -> None:
+        self._data = {}
+
+    def has(self, a: str, b: str, are_mutually_exclusive: bool) -> bool:
+        key1, key2 = (a, b) if a < b else (b, a)
+
+        map_ = self._data.get(key1)
+        if map_ is None:
+            return False
+        result = map_.get(key2)
         if result is None:
             return False
-        # `are_mutually_exclusive` being False is a superset of being True, hence if we
-        # want to know if this PairSet "has" these two with no exclusivity, we have to
-        # ensure it was added as such.
-        if not are_mutually_exclusive:
-            return not result
-        return True
 
-    def add(self, a: str, b: str, are_mutually_exclusive: bool):
-        self._pair_set_add(a, b, are_mutually_exclusive)
-        self._pair_set_add(b, a, are_mutually_exclusive)
-        return self
+        # are_mutually_exclusive being False is a superset of being True,
+        # hence if we want to know if this PairSet "has" these two with no exclusivity,
+        # we have to ensure it was added as such.
+        return True if are_mutually_exclusive else are_mutually_exclusive == result
 
-    def _pair_set_add(self, a: str, b: str, are_mutually_exclusive: bool):
-        a_map = self._data.get(a)
-        if not a_map:
-            self._data[a] = a_map = {}
-        a_map[b] = are_mutually_exclusive
+    def add(self, a: str, b: str, are_mutually_exclusive: bool) -> None:
+        key1, key2 = (a, b) if a < b else (b, a)
+
+        map_ = self._data.get(key1)
+        if map_ is None:
+            self._data[key1] = {key2: are_mutually_exclusive}
+        else:
+            map_[key2] = are_mutually_exclusive
