@@ -1,10 +1,10 @@
 import re
 from functools import partial
-from typing import Any, List
+from typing import Any, Optional
 
 from ...error import GraphQLError
 from ...language import TypeDefinitionNode, TypeExtensionNode
-from ...pyutils import did_you_mean, suggestion_list
+from ...pyutils import did_you_mean, inspect, suggestion_list
 from ...type import (
     is_enum_type,
     is_input_object_type,
@@ -15,20 +15,7 @@ from ...type import (
 )
 from . import SDLValidationContext, SDLValidationRule
 
-__all__ = [
-    "PossibleTypeExtensionsRule",
-    "extending_unknown_type_message",
-    "extending_different_type_kind_message",
-]
-
-
-def extending_unknown_type_message(type_name: str, suggested_types: List[str]) -> str:
-    hint = did_you_mean([f"'{s}'" for s in suggested_types])
-    return f"Cannot extend type '{type_name}' because it is not defined.{hint}"
-
-
-def extending_different_type_kind_message(type_name: str, kind: str) -> str:
-    return f"Cannot extend non-{kind} type '{type_name}'."
+__all__ = ["PossibleTypeExtensionsRule"]
 
 
 class PossibleTypeExtensionsRule(SDLValidationRule):
@@ -37,7 +24,7 @@ class PossibleTypeExtensionsRule(SDLValidationRule):
     A type extension is only valid if the type is defined and has the same kind.
     """
 
-    def __init__(self, context: SDLValidationContext) -> None:
+    def __init__(self, context: SDLValidationContext):
         super().__init__(context)
         self.schema = context.schema
         self.defined_types = {
@@ -46,32 +33,27 @@ class PossibleTypeExtensionsRule(SDLValidationRule):
             if isinstance(def_, TypeDefinitionNode)
         }
 
-    def check_extension(self, node: TypeExtensionNode, *_args):
+    def check_extension(self, node: TypeExtensionNode, *_args: Any) -> None:
         schema = self.schema
         type_name = node.name.value
         def_node = self.defined_types.get(type_name)
         existing_type = schema.get_type(type_name) if schema else None
 
+        expected_kind: Optional[str]
         if def_node:
             expected_kind = def_kind_to_ext_kind(def_node.kind)
-            if expected_kind != node.kind:
-                self.report_error(
-                    GraphQLError(
-                        extending_different_type_kind_message(
-                            type_name, extension_kind_to_type_name(expected_kind)
-                        ),
-                        [def_node, node],
-                    )
-                )
         elif existing_type:
             expected_kind = type_to_ext_kind(existing_type)
+        else:
+            expected_kind = None
+
+        if expected_kind:
             if expected_kind != node.kind:
+                kind_str = extension_kind_to_type_name(node.kind)
                 self.report_error(
                     GraphQLError(
-                        extending_different_type_kind_message(
-                            type_name, extension_kind_to_type_name(expected_kind)
-                        ),
-                        node,
+                        f"Cannot extend non-{kind_str} type '{type_name}'.",
+                        [def_node, node] if def_node else node,
                     )
                 )
         else:
@@ -81,7 +63,8 @@ class PossibleTypeExtensionsRule(SDLValidationRule):
             suggested_types = suggestion_list(type_name, all_type_names)
             self.report_error(
                 GraphQLError(
-                    extending_unknown_type_message(type_name, suggested_types),
+                    f"Cannot extend type '{type_name}' because it is not defined."
+                    + did_you_mean(suggested_types),
                     node.name,
                 )
             )
@@ -97,18 +80,19 @@ def_kind_to_ext_kind = partial(re.compile("(?<=_type_)definition$").sub, "extens
 def type_to_ext_kind(type_: Any) -> str:
     if is_scalar_type(type_):
         return "scalar_type_extension"
-    elif is_object_type(type_):
+    if is_object_type(type_):
         return "object_type_extension"
-    elif is_interface_type(type_):
+    if is_interface_type(type_):
         return "interface_type_extension"
-    elif is_union_type(type_):
+    if is_union_type(type_):
         return "union_type_extension"
-    elif is_enum_type(type_):
+    if is_enum_type(type_):
         return "enum_type_extension"
-    elif is_input_object_type(type_):
+    if is_input_object_type(type_):
         return "input_object_type_extension"
-    else:
-        return "unknown_type_extension"
+
+    # Not reachable. All possible types have been considered.
+    raise TypeError(f"Unexpected type: {inspect(type_)}.")
 
 
 _type_names_for_extension_kinds = {
