@@ -1,12 +1,10 @@
 import asyncio
-from typing import cast, Any, Awaitable, Optional
-
-from pytest import mark, raises
+from typing import Any, Awaitable, Optional, cast
 
 from graphql.error import GraphQLError
 from graphql.execution import execute, execute_sync
-from graphql.language import parse, FieldNode, OperationDefinitionNode
-from graphql.pyutils import inspect, Undefined
+from graphql.language import FieldNode, OperationDefinitionNode, parse
+from graphql.pyutils import Undefined, inspect
 from graphql.type import (
     GraphQLArgument,
     GraphQLBoolean,
@@ -17,12 +15,13 @@ from graphql.type import (
     GraphQLNonNull,
     GraphQLObjectType,
     GraphQLResolveInfo,
-    GraphQLSchema,
     GraphQLScalarType,
+    GraphQLSchema,
     GraphQLString,
     GraphQLUnionType,
     ResponsePath,
 )
+from pytest import mark, raises
 
 
 def describe_execute_handles_basic_execution_tasks():
@@ -567,6 +566,54 @@ def describe_execute_handles_basic_execution_tasks():
             ],
         )
 
+    @mark.filterwarnings("ignore:.* was never awaited:RuntimeWarning")
+    def handles_sync_errors_combined_with_async_ones():
+        is_async_resolver_finished = False
+
+        async def async_resolver(_obj, _info):
+            nonlocal is_async_resolver_finished
+            is_async_resolver_finished = True  # pragma: no cover
+
+        schema = GraphQLSchema(
+            GraphQLObjectType(
+                "Query",
+                {
+                    "syncNullError": GraphQLField(
+                        GraphQLNonNull(GraphQLString), resolve=lambda _obj, _info: None
+                    ),
+                    "asyncNullError": GraphQLField(
+                        GraphQLNonNull(GraphQLString), resolve=async_resolver
+                    ),
+                },
+            )
+        )
+
+        document = parse(
+            """
+            {
+              asyncNullError
+              syncNullError
+            }
+            """
+        )
+
+        result = execute(schema, document)
+
+        assert is_async_resolver_finished is False
+
+        assert result == (
+            None,
+            [
+                {
+                    "message": "Cannot return null"
+                    " for non-nullable field Query.syncNullError.",
+                    "locations": [(4, 15)],
+                    "path": ["syncNullError"],
+                }
+            ],
+        )
+
+    @mark.filterwarnings("ignore:.* was never awaited:RuntimeWarning")
     def full_response_path_is_included_for_non_nullable_fields():
         def resolve_ok(*_args):
             return {}
@@ -616,6 +663,7 @@ def describe_execute_handles_basic_execution_tasks():
             ],
         )
 
+    @mark.filterwarnings("ignore:.* was never awaited:RuntimeWarning")
     def uses_the_inline_operation_if_no_operation_name_is_provided():
         schema = GraphQLSchema(
             GraphQLObjectType("Type", {"a": GraphQLField(GraphQLString)})
@@ -629,6 +677,7 @@ def describe_execute_handles_basic_execution_tasks():
         result = execute_sync(schema, document, Data())
         assert result == ({"a": "b"}, None)
 
+    @mark.filterwarnings("ignore:.* was never awaited:RuntimeWarning")
     def uses_the_only_operation_if_no_operation_name_is_provided():
         schema = GraphQLSchema(
             GraphQLObjectType("Type", {"a": GraphQLField(GraphQLString)})
@@ -642,6 +691,7 @@ def describe_execute_handles_basic_execution_tasks():
         result = execute_sync(schema, document, Data())
         assert result == ({"a": "b"}, None)
 
+    @mark.filterwarnings("ignore:.* was never awaited:RuntimeWarning")
     def uses_the_named_operation_if_operation_name_is_provided():
         schema = GraphQLSchema(
             GraphQLObjectType("Type", {"a": GraphQLField(GraphQLString)})
