@@ -1,9 +1,12 @@
 import asyncio
+from typing import Any, Callable, Dict, List
 
-from typing import Any, Dict, List, Callable
-
-from pytest import mark, raises
-
+from graphql.execution import (
+    ExecutionResult,
+    MapAsyncIterator,
+    create_source_event_stream,
+    subscribe,
+)
 from graphql.language import parse
 from graphql.pyutils import SimplePubSub
 from graphql.type import (
@@ -16,10 +19,10 @@ from graphql.type import (
     GraphQLSchema,
     GraphQLString,
 )
-from graphql.execution import create_source_event_stream, subscribe, MapAsyncIterator
+from pytest import mark, raises
 
 try:
-    anext
+    anext  # type: ignore
 except NameError:  # pragma: no cover (Python < 3.10)
     # noinspection PyShadowingBuiltins
     async def anext(iterator):
@@ -448,6 +451,8 @@ def describe_subscription_initialization_phase():
         # resolve to an ExecutionResult that contains an informative error description.
         result = await subscribe(schema, document, variable_values=variable_values)
 
+        assert isinstance(result, ExecutionResult)
+
         assert result == (
             None,
             [
@@ -459,7 +464,9 @@ def describe_subscription_initialization_phase():
             ],
         )
 
-        assert result.errors[0].original_error is None  # type: ignore
+        errors = result.errors
+        assert errors
+        assert errors[0].original_error
 
 
 # Once a subscription returns a valid AsyncIterator, it can still yield errors.
@@ -855,7 +862,7 @@ def describe_subscription_publish_phase():
         subscription = await subscribe(schema, document)
         assert isinstance(subscription, MapAsyncIterator)
 
-        assert await (anext(subscription)) == ({"newMessage": "Hello"}, None)
+        assert await anext(subscription) == ({"newMessage": "Hello"}, None)
 
         with raises(RuntimeError) as exc_info:
             await anext(subscription)
