@@ -6,19 +6,19 @@ def describe_did_you_mean():
         assert did_you_mean([]) == ""
 
     def handles_single_suggestion():
-        assert did_you_mean(["A"]) == " Did you mean A?"
+        assert did_you_mean(["A"]) == " Did you mean 'A'?"
 
     def handles_two_suggestions():
-        assert did_you_mean(["A", "B"]) == " Did you mean A or B?"
+        assert did_you_mean(["A", "B"]) == " Did you mean 'A' or 'B'?"
 
     def handles_multiple_suggestions():
-        assert did_you_mean(["A", "B", "C"]) == " Did you mean A, B or C?"
+        assert did_you_mean(["A", "B", "C"]) == " Did you mean 'A', 'B', or 'C'?"
 
     def limits_to_five_suggestions():
         assert (
             did_you_mean(["A", "B", "C", "D", "E", "F"])
-            == " Did you mean A, B, C, D or E?"
+            == " Did you mean 'A', 'B', 'C', 'D', or 'E'?"
         )
 
     def adds_sub_message():
-        assert did_you_mean(["A"], "the letter") == " Did you mean the letter A?"
+        assert did_you_mean(["A"], "the letter") == " Did you mean the letter 'A'?"
