@@ -1,5 +1,6 @@
-from pytest import raises  # type: ignore
+from pytest import raises
 
+from graphql.error import GraphQLError
 from graphql.language import DirectiveLocation, DirectiveDefinitionNode, Node
 from graphql.type import GraphQLArgument, GraphQLDirective, GraphQLInt, GraphQLString
 
@@ -18,11 +19,11 @@ def describe_type_system_directive():
             ast_node=node,
         )
         assert directive.name == "test"
-        assert directive.locations == locations
+        assert directive.locations == tuple(locations)
         assert directive.args == {"arg": arg}
         assert directive.is_repeatable is True
         assert directive.description == "test description"
-        assert directive.extensions is None
+        assert directive.extensions == {}
         assert directive.ast_node is node
 
     def defines_a_directive_with_no_args():
@@ -32,8 +33,8 @@ def describe_type_system_directive():
         assert directive.name == "Foo"
         assert directive.args == {}
         assert directive.is_repeatable is False
-        assert directive.extensions is None
-        assert directive.locations == locations
+        assert directive.extensions == {}
+        assert directive.locations == tuple(locations)
 
     def defines_a_directive_with_multiple_args():
         args = {
@@ -46,7 +47,7 @@ def describe_type_system_directive():
         assert directive.name == "Foo"
         assert directive.args == args
         assert directive.is_repeatable is False
-        assert directive.locations == locations
+        assert directive.locations == tuple(locations)
 
     def defines_a_repeatable_directive():
         locations = [DirectiveLocation.QUERY]
@@ -55,7 +56,7 @@ def describe_type_system_directive():
         assert directive.name == "Foo"
         assert directive.args == {}
         assert directive.is_repeatable is True
-        assert directive.locations == locations
+        assert directive.locations == tuple(locations)
 
     def directive_accepts_input_types_as_arguments():
         # noinspection PyTypeChecker
@@ -71,10 +72,10 @@ def describe_type_system_directive():
         directive = GraphQLDirective(
             name="Foo", locations=["SCHEMA", "OBJECT"]  # type: ignore
         )
-        assert directive.locations == [
+        assert directive.locations == (
             DirectiveLocation.SCHEMA,
             DirectiveLocation.OBJECT,
-        ]
+        )
 
     def directive_has_str():
         directive = GraphQLDirective("foo", [])
@@ -108,17 +109,28 @@ def describe_type_system_directive():
         assert not directive == other_directive
         assert directive != other_directive
 
-    def rejects_an_unnamed_directive():
-        with raises(TypeError) as exc_info:
-            # noinspection PyTypeChecker
-            GraphQLDirective(None, locations=[])  # type: ignore
-        assert str(exc_info.value) == "Directive must be named."
-
     def rejects_a_directive_with_incorrectly_typed_name():
+        with raises(TypeError, match="missing .* required .* 'name'"):
+            # noinspection PyArgumentList
+            GraphQLDirective()  # type: ignore
         with raises(TypeError) as exc_info:
             # noinspection PyTypeChecker
-            GraphQLDirective({"bad": True}, locations=[])  # type: ignore
-        assert str(exc_info.value) == "The directive name must be a string."
+            GraphQLDirective(None, [])  # type: ignore
+        assert str(exc_info.value) == "Must provide name."
+        with raises(TypeError) as exc_info:
+            # noinspection PyTypeChecker
+            GraphQLDirective(42, {})  # type: ignore
+        assert str(exc_info.value) == "Expected name to be a string."
+
+    def rejects_a_directive_with_invalid_name():
+        with raises(GraphQLError) as exc_info:
+            GraphQLDirective("", [])
+        assert str(exc_info.value) == "Expected name to be a non-empty string."
+        with raises(GraphQLError) as exc_info:
+            GraphQLDirective("bad-name", [])
+        assert str(exc_info.value) == (
+            "Names must only contain [_a-zA-Z0-9] but 'bad-name' does not."
+        )
 
     def rejects_a_directive_with_incorrectly_typed_args():
         with raises(TypeError) as exc_info:
@@ -148,6 +160,17 @@ def describe_type_system_directive():
             "Foo args must be GraphQLArgument or input type objects."
         )
 
+    def rejects_a_directive_with_incorrectly_named_args():
+        with raises(GraphQLError) as exc_info:
+            GraphQLDirective(
+                "Foo",
+                locations=[DirectiveLocation.QUERY],
+                args={"bad-name": GraphQLArgument(GraphQLString)},
+            )
+        assert str(exc_info.value) == (
+            "Names must only contain [_a-zA-Z0-9] but 'bad-name' does not."
+        )
+
     def rejects_a_directive_with_incorrectly_typed_repeatable_flag():
         with raises(TypeError) as exc_info:
             # noinspection PyTypeChecker
