@@ -3,14 +3,7 @@ from typing import Union
 from pytest import raises
 
 from graphql import graphql_sync
-from graphql.language import (
-    parse,
-    print_ast,
-    DocumentNode,
-    StringValueNode,
-    TypeDefinitionNode,
-)
-from graphql.pyutils import FrozenList
+from graphql.language import parse, print_ast
 from graphql.type import (
     GraphQLArgument,
     GraphQLBoolean,
@@ -36,7 +29,6 @@ from graphql.utilities import (
     build_schema,
     concat_ast,
     extend_schema,
-    get_description,
     print_schema,
 )
 
@@ -57,30 +49,33 @@ TypeWithExtensionAstNodes = Union[
 ]
 
 
-def print_extension_nodes(obj: TypeWithExtensionAstNodes) -> str:
+def expect_extension_ast_nodes(obj: TypeWithExtensionAstNodes, expected: str) -> None:
     assert obj is not None and obj.extension_ast_nodes is not None
-    return print_ast(DocumentNode(definitions=obj.extension_ast_nodes))
+    assert "\n\n".join(print_ast(node) for node in obj.extension_ast_nodes) == expected
 
 
-def print_schema_changes(schema: GraphQLSchema, extended_schema: GraphQLSchema) -> str:
-    schema_definitions = [
-        print_ast(definition) for definition in parse(print_schema(schema)).definitions
-    ]
-    ast = parse(print_schema(extended_schema))
-    return print_ast(
-        DocumentNode(
-            definitions=FrozenList(
-                node
-                for node in ast.definitions
-                if print_ast(node) not in schema_definitions
-            )
-        )
-    )
-
-
-def print_ast_node(obj: TypeWithAstNode) -> str:
+def expect_ast_node(obj: TypeWithAstNode, expected: str) -> None:
     assert obj is not None and obj.ast_node is not None
-    return print_ast(obj.ast_node)
+    assert print_ast(obj.ast_node) == expected
+
+
+def expect_schema_changes(
+    schema: GraphQLSchema, extended_schema: GraphQLSchema, expected: str
+) -> None:
+    schema_definitions = {
+        print_ast(node) for node in parse(print_schema(schema)).definitions
+    }
+    assert (
+        "\n\n".join(
+            schema_def
+            for schema_def in (
+                print_ast(node)
+                for node in parse(print_schema(extended_schema)).definitions
+            )
+            if schema_def not in schema_definitions
+        )
+        == expected
+    )
 
 
 def describe_extend_schema():
@@ -139,17 +134,21 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, parse(extension_sdl))
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            '''
-            type SomeObject implements AnotherInterface & SomeInterface {
-              self: SomeObject
-              tree: [SomeObject]!
-              """Old field description."""
-              oldField: String
-              """New field description."""
-              newField(arg: Boolean): String
-            }
-            '''
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                '''
+                type SomeObject implements AnotherInterface & SomeInterface {
+                  self: SomeObject
+                  tree: [SomeObject]!
+                  """Old field description."""
+                  oldField: String
+                  """New field description."""
+                  newField(arg: Boolean): String
+                }
+                '''
+            ),
         )
 
     def extends_objects_with_standard_type_fields():
@@ -222,15 +221,19 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            '''
-            enum SomeEnum {
-              """Old value description."""
-              OLD_VALUE
-              """New value description."""
-              NEW_VALUE
-            }
-            '''
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                '''
+                enum SomeEnum {
+                  """Old value description."""
+                  OLD_VALUE
+                  """New value description."""
+                  NEW_VALUE
+                }
+                '''
+            ),
         )
 
     def extends_unions_by_adding_new_types():
@@ -255,10 +258,14 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
-            union SomeUnion = Foo | Biz | Bar
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
+                union SomeUnion = Foo | Biz | Bar
+                """
+            ),
         )
 
     def allows_extension_of_union_by_adding_itself():
@@ -306,15 +313,19 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            '''
-            input SomeInput {
-              """Old field description."""
-              oldField: String
-              """New field description."""
-              newField: String
-            }
-            '''
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                '''
+                input SomeInput {
+                  """Old field description."""
+                  oldField: String
+                  """New field description."""
+                  newField: String
+                }
+                '''
+            ),
         )
 
     def extends_scalars_by_adding_new_directives():
@@ -339,11 +350,10 @@ def describe_extend_schema():
             """
         )
         extended_schema = extend_schema(schema, parse(extension_sdl))
+        some_scalar = assert_scalar_type(extended_schema.get_type("SomeScalar"))
 
         assert validate_schema(extended_schema) == []
-
-        some_scalar = assert_scalar_type(extended_schema.get_type("SomeScalar"))
-        assert print_extension_nodes(some_scalar) == extension_sdl
+        expect_extension_ast_nodes(some_scalar, extension_sdl)
 
     def extends_scalars_by_adding_specified_by_directive():
         schema = build_schema(
@@ -371,7 +381,7 @@ def describe_extend_schema():
         assert foo.specified_by_url == "https://example.com/foo_spec"
 
         assert validate_schema(extended_schema) == []
-        assert print_extension_nodes(foo) == extension_sdl
+        expect_extension_ast_nodes(foo, extension_sdl)
 
     def correctly_assigns_ast_nodes_to_new_and_extended_types():
         schema = build_schema(
@@ -487,11 +497,11 @@ def describe_extend_schema():
         )
         test_directive = assert_directive(extended_twice_schema.get_directive("test"))
 
-        assert test_type.extension_ast_nodes is None
-        assert test_enum.extension_ast_nodes is None
-        assert test_union.extension_ast_nodes is None
-        assert test_input.extension_ast_nodes is None
-        assert test_interface.extension_ast_nodes is None
+        assert test_type.extension_ast_nodes == ()
+        assert test_enum.extension_ast_nodes == ()
+        assert test_union.extension_ast_nodes == ()
+        assert test_input.extension_ast_nodes == ()
+        assert test_interface.extension_ast_nodes == ()
 
         assert query.extension_ast_nodes
         assert len(query.extension_ast_nodes) == 2
@@ -522,46 +532,30 @@ def describe_extend_schema():
         } == {*first_extension_ast.definitions, *second_extension_ast.definitions}
 
         new_field = query.fields["newField"]
-        assert print_ast_node(new_field) == "newField(testArg: TestInput): TestEnum"
-        assert print_ast_node(new_field.args["testArg"]) == "testArg: TestInput"
-        assert (
-            print_ast_node(query.fields["oneMoreNewField"])
-            == "oneMoreNewField: TestUnion"
-        )
+        expect_ast_node(new_field, "newField(testArg: TestInput): TestEnum")
+        expect_ast_node(new_field.args["testArg"], "testArg: TestInput")
+        expect_ast_node(query.fields["oneMoreNewField"], "oneMoreNewField: TestUnion")
 
-        new_value = some_enum.values["NEW_VALUE"]
-        assert print_ast_node(new_value) == "NEW_VALUE"
+        expect_ast_node(some_enum.values["NEW_VALUE"], "NEW_VALUE")
 
         one_more_new_value = some_enum.values["ONE_MORE_NEW_VALUE"]
-        assert print_ast_node(one_more_new_value) == "ONE_MORE_NEW_VALUE"
-        assert print_ast_node(some_input.fields["newField"]) == "newField: String"
-        assert (
-            print_ast_node(some_input.fields["oneMoreNewField"])
-            == "oneMoreNewField: String"
-        )
-        assert print_ast_node(some_interface.fields["newField"]) == "newField: String"
-        assert (
-            print_ast_node(some_interface.fields["oneMoreNewField"])
-            == "oneMoreNewField: String"
+        expect_ast_node(one_more_new_value, "ONE_MORE_NEW_VALUE")
+        expect_ast_node(some_input.fields["newField"], "newField: String")
+        expect_ast_node(some_input.fields["oneMoreNewField"], "oneMoreNewField: String")
+        expect_ast_node(some_interface.fields["newField"], "newField: String")
+        expect_ast_node(
+            some_interface.fields["oneMoreNewField"], "oneMoreNewField: String"
         )
 
-        assert (
-            print_ast_node(test_input.fields["testInputField"])
-            == "testInputField: TestEnum"
-        )
+        expect_ast_node(test_input.fields["testInputField"], "testInputField: TestEnum")
 
-        test_value = test_enum.values["TEST_VALUE"]
-        assert print_ast_node(test_value) == "TEST_VALUE"
+        expect_ast_node(test_enum.values["TEST_VALUE"], "TEST_VALUE")
 
-        assert (
-            print_ast_node(test_interface.fields["interfaceField"])
-            == "interfaceField: String"
+        expect_ast_node(
+            test_interface.fields["interfaceField"], "interfaceField: String"
         )
-        assert (
-            print_ast_node(test_type.fields["interfaceField"])
-            == "interfaceField: String"
-        )
-        assert print_ast_node(test_directive.args["arg"]) == "arg: Int"
+        expect_ast_node(test_type.fields["interfaceField"], "interfaceField: String")
+        expect_ast_node(test_directive.args["arg"], "arg: Int")
 
     def builds_types_with_deprecated_fields_and_values():
         schema = GraphQLSchema()
@@ -580,12 +574,10 @@ def describe_extend_schema():
 
         some_type = assert_object_type(extended_schema.get_type("SomeObject"))
         deprecated_field = some_type.fields["deprecatedField"]
-        assert deprecated_field.is_deprecated is True
         assert deprecated_field.deprecation_reason == "not used anymore"
 
         some_enum = assert_enum_type(extended_schema.get_type("SomeEnum"))
         deprecated_enum = some_enum.values["DEPRECATED_VALUE"]
-        assert deprecated_enum.is_deprecated is True
         assert deprecated_enum.deprecation_reason == "do not use"
 
     def extends_objects_with_deprecated_fields():
@@ -601,7 +593,6 @@ def describe_extend_schema():
 
         some_type = assert_object_type(extended_schema.get_type("SomeObject"))
         deprecated_field = some_type.fields["deprecatedField"]
-        assert deprecated_field.is_deprecated is True
         assert deprecated_field.deprecation_reason == "not used anymore"
 
     def extend_enums_with_deprecated_values():
@@ -617,7 +608,6 @@ def describe_extend_schema():
 
         some_enum = assert_enum_type(extended_schema.get_type("SomeEnum"))
         deprecated_value = some_enum.values["DEPRECATED_VALUE"]
-        assert deprecated_value.is_deprecated is True
         assert deprecated_value.deprecation_reason == "do not use"
 
     def adds_new_unused_types():
@@ -656,7 +646,7 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, parse(extension_sdl))
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == extension_sdl
+        expect_schema_changes(schema, extended_schema, extension_sdl)
 
     def extends_objects_by_adding_new_fields_with_arguments():
         schema = build_schema(
@@ -684,8 +674,11 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
             type SomeObject {
               newField(arg1: String, arg2: NewInputObj!): String
             }
@@ -696,6 +689,7 @@ def describe_extend_schema():
               field3: String!
             }
             """
+            ),
         )
 
     def extends_objects_by_adding_new_fields_with_existing_types():
@@ -719,12 +713,16 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
             type SomeObject {
               newField(arg1: SomeEnum!): SomeEnum
             }
             """
+            ),
         )
 
     def extends_objects_by_adding_implemented_interfaces():
@@ -751,12 +749,16 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
             type SomeObject implements SomeInterface {
               foo: String
             }
             """
+            ),
         )
 
     def extends_objects_by_including_new_types():
@@ -804,9 +806,11 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
             type SomeObject {
               oldField: String
               newObject: NewObject
@@ -816,7 +820,8 @@ def describe_extend_schema():
               newEnum: NewEnum
               newTree: [SomeObject]!
             }\n"""
-            + new_types_sdl
+                + new_types_sdl
+            ),
         )
 
     def extends_objects_by_adding_implemented_new_interfaces():
@@ -849,8 +854,11 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
             type SomeObject implements OldInterface & NewInterface {
               oldField: String
               newField: String
@@ -860,6 +868,7 @@ def describe_extend_schema():
               newField: String
             }
             """
+            ),
         )
 
     def extends_different_types_multiple_times():
@@ -918,7 +927,7 @@ def describe_extend_schema():
             """
         )
         schema_with_new_types = extend_schema(schema, parse(new_types_sdl))
-        assert print_schema_changes(schema, schema_with_new_types) == new_types_sdl
+        expect_schema_changes(schema, schema_with_new_types, new_types_sdl)
 
         extend_ast = parse(
             """
@@ -956,35 +965,37 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema_with_new_types, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert (
-            print_schema_changes(schema, extended_schema)
-            == dedent(
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
                 """
-            scalar SomeScalar @specifiedBy(url: "http://example.com/foo_spec")
+                scalar SomeScalar @specifiedBy(url: "http://example.com/foo_spec")
 
-            type SomeObject implements SomeInterface & NewInterface & AnotherNewInterface {
-              oldField: String
-              newField: String
-              anotherNewField: String
-            }
+                type SomeObject implements SomeInterface & NewInterface & AnotherNewInterface {
+                  oldField: String
+                  newField: String
+                  anotherNewField: String
+                }
 
-            enum SomeEnum {
-              OLD_VALUE
-              NEW_VALUE
-              ANOTHER_NEW_VALUE
-            }
+                enum SomeEnum {
+                  OLD_VALUE
+                  NEW_VALUE
+                  ANOTHER_NEW_VALUE
+                }
 
-            union SomeUnion = SomeObject | NewObject | AnotherNewObject
+                union SomeUnion = SomeObject | NewObject | AnotherNewObject
 
-            input SomeInput {
-              oldField: String
-              newField: String
-              anotherNewField: String
-            }
+                input SomeInput {
+                  oldField: String
+                  newField: String
+                  anotherNewField: String
+                }
 
-            """  # noqa: E501
+                """  # noqa: E501
             )
-            + new_types_sdl
+            + "\n\n"
+            + new_types_sdl,
         )
 
     def extends_interfaces_by_adding_new_fields():
@@ -1025,23 +1036,27 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
-            interface SomeInterface {
-              oldField: String
-              newField: String
-            }
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
+                interface SomeInterface {
+                  oldField: String
+                  newField: String
+                }
 
-            interface AnotherInterface implements SomeInterface {
-              oldField: String
-              newField: String
-            }
+                interface AnotherInterface implements SomeInterface {
+                  oldField: String
+                  newField: String
+                }
 
-            type SomeObject implements SomeInterface & AnotherInterface {
-              oldField: String
-              newField: String
-            }
-            """
+                type SomeObject implements SomeInterface & AnotherInterface {
+                  oldField: String
+                  newField: String
+                }
+                """
+            ),
         )
 
     def extends_interfaces_by_adding_new_implemented_interfaces():
@@ -1082,22 +1097,26 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
-            interface AnotherInterface implements SomeInterface & NewInterface {
-              oldField: String
-              newField: String
-            }
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
+                interface AnotherInterface implements SomeInterface & NewInterface {
+                  oldField: String
+                  newField: String
+                }
 
-            type SomeObject implements SomeInterface & AnotherInterface & NewInterface {
-              oldField: String
-              newField: String
-            }
+                type SomeObject implements SomeInterface & AnotherInterface & NewInterface {
+                  oldField: String
+                  newField: String
+                }
 
-            interface NewInterface {
-              newField: String
-            }
-            """
+                interface NewInterface {
+                  newField: String
+                }
+                """  # noqa: E501
+            ),
         )
 
     def allows_extension_of_interface_with_missing_object_fields():
@@ -1126,13 +1145,17 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema)
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
-            interface SomeInterface {
-              oldField: SomeInterface
-              newField: String
-            }
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
+                interface SomeInterface {
+                  oldField: SomeInterface
+                  newField: String
+                }
+                """
+            ),
         )
 
     def extends_interfaces_multiple_times():
@@ -1161,14 +1184,18 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, extend_ast)
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == dedent(
-            """
-            interface SomeInterface {
-              some: SomeInterface
-              newFieldA: Int
-              newFieldB(test: Boolean): String
-            }
-            """
+        expect_schema_changes(
+            schema,
+            extended_schema,
+            dedent(
+                """
+                interface SomeInterface {
+                  some: SomeInterface
+                  newFieldA: Int
+                  newFieldB(test: Boolean): String
+                }
+                """
+            ),
         )
 
     def may_extend_mutations_and_subscriptions():
@@ -1242,7 +1269,7 @@ def describe_extend_schema():
         extended_schema = extend_schema(schema, parse(extension_sdl))
 
         assert validate_schema(extended_schema) == []
-        assert print_schema_changes(schema, extended_schema) == extension_sdl
+        expect_schema_changes(schema, extended_schema, extension_sdl)
 
     def rejects_invalid_sdl():
         schema = GraphQLSchema()
@@ -1351,7 +1378,7 @@ def describe_extend_schema():
 
             query_type = assert_object_type(extended_schema.query_type)
             assert query_type.name == "Foo"
-            assert print_ast_node(extended_schema) + "\n" == extension_sdl
+            expect_ast_node(extended_schema, extension_sdl)
 
         def adds_new_root_types_via_schema_extension():
             schema = build_schema(
@@ -1371,7 +1398,7 @@ def describe_extend_schema():
 
             mutation_type = assert_object_type(extended_schema.mutation_type)
             assert mutation_type.name == "MutationRoot"
-            assert print_extension_nodes(extended_schema) == extension_sdl
+            expect_extension_ast_nodes(extended_schema, extension_sdl)
 
         def adds_directive_via_schema_extension():
             schema = build_schema(
@@ -1388,7 +1415,7 @@ def describe_extend_schema():
             )
             extended_schema = extend_schema(schema, parse(extension_sdl))
 
-            assert print_extension_nodes(extended_schema) == extension_sdl
+            expect_extension_ast_nodes(extended_schema, extension_sdl)
 
         def adds_multiple_new_root_types_via_schema_extension():
             schema = build_schema("type Query")
@@ -1460,31 +1487,19 @@ def describe_extend_schema():
             second_extend_ast = parse("extend schema @foo")
             extended_twice_schema = extend_schema(extended_schema, second_extend_ast)
 
-            assert print_extension_nodes(extended_twice_schema) == dedent(
-                """
-                extend schema {
-                  mutation: Mutation
-                }
+            expect_extension_ast_nodes(
+                extended_twice_schema,
+                dedent(
+                    """
+                    extend schema {
+                      mutation: Mutation
+                    }
 
-                extend schema {
-                  subscription: Subscription
-                }
+                    extend schema {
+                      subscription: Subscription
+                    }
 
-                extend schema @foo
-                """
+                    extend schema @foo
+                    """
+                ),
             )
-
-
-def describe_get_description():
-    def returns_description_of_type_definition_node():
-        assert (
-            get_description(
-                TypeDefinitionNode(
-                    description=StringValueNode(value="This is a type definition")
-                )
-            )
-            == "This is a type definition"
-        )
-
-    def returns_none_for_node_without_description():
-        assert get_description(StringValueNode(value="Just a string value")) is None
