@@ -1,16 +1,15 @@
-from typing import Dict
-
 from graphql.type import GraphQLSchema, GraphQLObjectType, GraphQLField, GraphQLString
 from graphql.utilities import (
     build_client_schema,
     print_schema,
     introspection_from_schema,
+    IntrospectionQuery,
 )
 
 from ..utils import dedent
 
 
-def introspection_to_sdl(introspection: Dict) -> str:
+def introspection_to_sdl(introspection: IntrospectionQuery) -> str:
     return print_schema(build_client_schema(introspection))
 
 
@@ -25,7 +24,8 @@ def describe_introspection_from_schema():
                 )
             },
             description="This is a simple type",
-        )
+        ),
+        description="This is a simple schema",
     )
 
     def converts_a_simple_schema():
@@ -33,6 +33,7 @@ def describe_introspection_from_schema():
 
         assert introspection_to_sdl(introspection) == dedent(
             '''
+            """This is a simple schema"""
             schema {
               query: Simple
             }
