@@ -1,6 +1,7 @@
 from math import isnan, nan
+from typing import Any, Dict, Optional
 
-from graphql.language import parse_value
+from graphql.language import parse_value, ValueNode
 from graphql.pyutils import Undefined
 from graphql.type import (
     GraphQLBoolean,
@@ -9,6 +10,7 @@ from graphql.type import (
     GraphQLID,
     GraphQLInputField,
     GraphQLInputObjectType,
+    GraphQLInputType,
     GraphQLInt,
     GraphQLList,
     GraphQLNonNull,
@@ -19,7 +21,11 @@ from graphql.utilities import value_from_ast
 
 
 def describe_value_from_ast():
-    def _value_from(value_text, type_, variables=None):
+    def _value_from(
+        value_text: str,
+        type_: GraphQLInputType,
+        variables: Optional[Dict[str, Any]] = None,
+    ):
         ast = parse_value(value_text)
         return value_from_ast(ast, type_, variables)
 
@@ -60,7 +66,7 @@ def describe_value_from_ast():
 
         assert _value_from('"value"', pass_through_scalar) == "value"
 
-        def throw_parse_literal(_node, _vars=None):
+        def throw_parse_literal(_node: ValueNode, _vars=None):
             raise RuntimeError("Test")
 
         throw_scalar = GraphQLScalarType(
@@ -71,9 +77,12 @@ def describe_value_from_ast():
 
         assert _value_from("value", throw_scalar) is Undefined
 
+        def undefined_parse_literal(_node: ValueNode, _vars=None):
+            return Undefined
+
         return_undefined_scalar = GraphQLScalarType(
             "ReturnUndefinedScalar",
-            parse_literal=lambda _node, _vars=None: Undefined,
+            parse_literal=undefined_parse_literal,
             parse_value=lambda value: value,  # pragma: no cover
         )
 
